@@ -1645,7 +1645,7 @@ Fullquery.prototype.capabilityFlagDefault = function ( flag ) {
         return true;
     } else if (flag.substring(0, 6) == "index-") {
         var index = flag.substring(6);
-        if (this.conf.fields[index])
+        if ( typeof(this.conf.fields[index]) != "undefined")
           return true;
           // note, do not return false if not there, other steps may still
           // make use of it.
@@ -1663,7 +1663,7 @@ Fullquery.prototype.capabilityFlagDefault = function ( flag ) {
                ( this.conf.range_BE || this.conf.range_E ) )
             return true;
           if ( flag == "index-keyword" &&
-             this.conf.defaultfield &&
+             /*this.conf.defaultfield && */
              this.conf.defaultfield != unsupported_value )
           return true; // unspecified index usually means a keyword.
     } else if (flag == "query-and") {
