@@ -61,7 +61,8 @@ IfElse.prototype.draw = function(surface) {
     xmlHelper.emptyChildren(surface);
     context.draw(surface);
   }
-  var add = xmlHelper.appendNode(tabs, 'button', null, {icon: 'add',
+  var add = xmlHelper.appendNode(tabs, 'button', null, {
+      image: 'chrome://cfbuilder/content/icons/tab-new.png',
       tooltiptext: 'Add another conditional block',
       style: 'min-width: 10px; margin: 0; padding: 0;' }); 
   add.addEventListener("click", function (e) {
@@ -71,7 +72,8 @@ IfElse.prototype.draw = function(surface) {
     context.blocks.splice(last, 0, new Block(context.task, 'if'+last, 'else if', context)); 
     refresh();
   }, false);
-  var left = xmlHelper.appendNode(tabs, 'button', null, {icon: 'go-back',
+  var left = xmlHelper.appendNode(tabs, 'button', null, {
+      image: 'chrome://cfbuilder/content/icons/go-previous.png',
       tooltiptext: 'Move this conditional before previous',
       style: 'min-width: 10px; margin: 0;' }); 
   left.addEventListener("click", function (e) {
@@ -83,7 +85,8 @@ IfElse.prototype.draw = function(surface) {
     context.blocks.splice(sel-1, 0, removed); 
     refresh(sel - 1);
   }, false);
-  var right = xmlHelper.appendNode(tabs, 'button', null, {icon: 'go-forward',
+  var right = xmlHelper.appendNode(tabs, 'button', null, {
+      image: 'chrome://cfbuilder/content/icons/go-next.png',
       tooltiptext: 'Move this conditional after next',
       style: 'min-width: 10px; margin: 0;' }); 
   right.addEventListener("click", function (e) {
@@ -95,7 +98,8 @@ IfElse.prototype.draw = function(surface) {
     context.blocks.splice(sel+1, 0, removed); 
     refresh(sel + 1);
   }, false);
-  var remove = xmlHelper.appendNode(tabs, 'button', null, {icon: "remove",
+  var remove = xmlHelper.appendNode(tabs, 'button', null, {
+      image: 'chrome://cfbuilder/content/icons/process-stop.png',
       style: 'min-width: 10px; margin: 0;' }); 
   remove.addEventListener("click", function (e) {
     let sel = tabs.selectedIndex;
