@@ -6,6 +6,9 @@ Components.utils.import('resource://indexdata/util/xmlHelper.js');
 Components.utils.import('resource://indexdata/util/xulHelper.js');
 Components.utils.import('resource://indexdata/util/htmlHelper.js');
 Components.utils.import('resource://indexdata/util/jsonPathHelper.js');
+Components.utils.import('resource://indexdata/util/logging.js');
+
+var logger = logging.getLogger();
 
 var NavTo = function () {
   this.conf = {};
@@ -17,7 +20,6 @@ var NavTo = function () {
   // 'url' - constant url to go to
   // 'jp'  - JSONpath to the variable that has the URL
   // Only one should exist at any one time!
-  // There is 'inline' as well... Not quite sure why.
   this.hl = null;
 };
 
@@ -27,9 +29,7 @@ NavTo.prototype.constructor = NavTo;
 NavTo.prototype.init = function(task) { };
 
 NavTo.prototype.draw = function(surface) {
-  // delete processed inline jps
-  delete this.conf.inline;
-
+  
   var context = this;
   var radiogroup = xmlHelper.appendNode(surface, "radiogroup");
 
@@ -106,8 +106,6 @@ NavTo.prototype.processConf = function () {
     while ((match = usedArgRegex.exec(url)) !== null) {
       usedArgs.push(match[1]);
     }
-    // process inline JSONpaths
-    this.conf.inline = jsonPathHelper.processInline(url);
   } else {
     // reading from a path instead
     if (this.conf.jp.path === "$.input") {
@@ -124,8 +122,12 @@ NavTo.prototype.getUrl = function (task) {
       if (!url) throw new StepError("URL not found in: " + this.conf.jp.path
                                      + "." + this.conf.jp.key);
     } else {
-      url = jsonPathHelper.applyInline(this.conf.inline, this.task.data);
-      if (!url) throw new StepError("URL not specified.");
+      url = jsonPathHelper.inlineReplace(this.conf.url, task.data);
+      if (!url) {
+        logger.debug("getUrl failed to get a (constant) url. " + this.conf.url  );
+        throw new StepError("URL not specified.");
+      }
+      logger.debug("getUrl did get a (constant) url. '" + this.conf.url );
     }
     return url;
 };
