@@ -134,7 +134,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
     if (mkdir(lockdir, 0775) == -1 && errno != EEXIST)
     {
         if (m_logger)
-            m_logger->printf("engine", "display: mkdir %s: %s",
+            m_logger->printf("engine", YLOG_WARN, "display: mkdir %s: %s",
                              lockdir, strerror(errno));
     }
     while (1)
@@ -154,7 +154,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
                 int x = errno;
                 pthread_mutex_unlock(&static_display_mutex);
                 if (m_logger)
-                    m_logger->printf("engine", "display open %s: %s",
+                    m_logger->printf("engine", YLOG_WARN, "display open %s: %s",
                                      wrbuf_cstr(fname_lck_file), strerror(x));
                 wrbuf_printf(wrbuf_error, "Could not open %s: %s",
                              wrbuf_cstr(fname_lck_file), strerror(x));
@@ -174,13 +174,14 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         if (dno == MAX_DISPLAY)
         {
             if (m_logger)
-                m_logger->printf("engine", "display dno=%d giving up", dno);
+                m_logger->printf("engine", YLOG_WARN,
+                                 "display dno=%d giving up", dno);
             wrbuf_printf(wrbuf_error, "display dno=%d giving up", dno);
             return false;
         }
     }
     if (m_logger)
-        m_logger->printf("engine", "display: lock %s",
+        m_logger->printf("engine", YLOG_LOG, "display: lock %s",
                          wrbuf_cstr(fname_lck_file));
 
     pid_t pid = 0;
@@ -191,7 +192,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
     {
         int x = errno;
         if (m_logger)
-            m_logger->printf("engine", "display: open %s: %s",
+            m_logger->printf("engine", YLOG_WARN, "display: open %s: %s",
                              wrbuf_cstr(x11_lock_fname), strerror(x));
         wrbuf_printf(wrbuf_error, "display: open %s: %s",
                      wrbuf_cstr(x11_lock_fname), strerror(x));
@@ -209,7 +210,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         if (no_read == -1)
         {
             if (m_logger)
-                m_logger->printf("engine", "display: read %s: %s",
+                m_logger->printf("engine", YLOG_WARN, "display: read %s: %s",
                                  wrbuf_cstr(x11_lock_fname), strerror(x));
             wrbuf_printf(wrbuf_error, "display: read %s: %s",
                          wrbuf_cstr(x11_lock_fname), strerror(x));
@@ -230,11 +231,11 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         if (m_logger)
         {
             if (r == -1)
-                m_logger->printf("engine",
+                m_logger->printf("engine", YLOG_WARN,
                                  "display: kill stale Xvfb PID=%ld: %s",
                                  (long) pid, strerror(x));
             else
-                m_logger->printf("engine",
+                m_logger->printf("engine", YLOG_WARN,
                                  "display: kill stale Xvfb PID=%ld",
                                  (long) pid);
         }
@@ -310,7 +311,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
     {
         int x = errno;
         if (m_logger)
-            m_logger->printf("engine", "write %s: %s",
+            m_logger->printf("engine", YLOG_WARN, "write %s: %s",
                              wrbuf_cstr(fname_lck_file), strerror(x));
         wrbuf_printf(wrbuf_error, "write %s: %s",
                      wrbuf_cstr(fname_lck_file), strerror(x));
@@ -322,7 +323,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
     wrbuf_printf(m_display, ":%d.0", display_base + dno);
 
     if (m_logger)
-        m_logger->printf("engine", "display: spawn DISPLAY=%s PID=%s",
+        m_logger->printf("engine", YLOG_LOG, "display: spawn DISPLAY=%s PID=%s",
              wrbuf_cstr(m_display), pidstr);
 
     int i;
@@ -332,7 +333,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         if (x11_display)
         {
             if (m_logger)
-                m_logger->printf("engine",
+                m_logger->printf("engine", YLOG_LOG,
                                  "display: XOpenDisplay OK for %s i=%d",
                                  wrbuf_cstr(m_display), i);
             XCloseDisplay(x11_display);
@@ -340,7 +341,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         }
 
         if (m_logger && i > 10)
-            m_logger->printf("engine",
+            m_logger->printf("engine", YLOG_WARN,
                              "display: XOpenDisplay FAIL for %s i=%d",
                              wrbuf_cstr(m_display), i);
 
@@ -353,14 +354,16 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
         {
             int x = errno;
             if (m_logger)
-                m_logger->printf("engine", "display: nanosleep errno=%d", x);
+                m_logger->printf("engine", YLOG_WARN,
+                                 "display: nanosleep errno=%d", x);
             if (x != EINTR)
                 break;
         }
     }
 
     if (m_logger)
-        m_logger->printf("engine", "display: Giving up for DISPLAY=%s",
+        m_logger->printf("engine", YLOG_WARN,
+                         "display: Giving up for DISPLAY=%s",
                          wrbuf_cstr(m_display));
     wrbuf_rewind(wrbuf_error);
     wrbuf_printf(wrbuf_error, "Xvfb start failure. DISPLAY=%s",
@@ -379,11 +382,11 @@ void CF_Display::close()
         if (m_logger)
         {
             if (r == 0)
-                m_logger->printf("engine",
+                m_logger->printf("engine", YLOG_DEBUG,
                                  "display: kill Xvfb DISPLAY=%s PID=%ld",
                                  wrbuf_cstr(m_display), (long) xvfb_pid);
             else
-                m_logger->printf("engine",
+                m_logger->printf("engine", YLOG_WARN,
                                  "display: kill Xvfb DISPLAY=%s PID=%ld: %s",
                                  wrbuf_cstr(m_display), (long) xvfb_pid,
                                  strerror(x));
