@@ -519,6 +519,9 @@ yf::CF::Session::~Session()
     delete engine;
     if (log_file != -1)
         close(log_file);
+    mp::wrbuf cf_log_fname;
+    wrbuf_printf(cf_log_fname, "%s.log", wrbuf_cstr(file_area));
+    unlink(wrbuf_cstr(cf_log_fname));
 }
 
 yf::CF::Rep::Rep()
